# Hex Augmentations


## Geometric Transformations

::: flyvis.datasets.augmentation.hex.HexRotate
::: flyvis.datasets.augmentation.hex.HexFlip

## Intensity Transformations

::: flyvis.datasets.augmentation.hex.ContrastBrightness
::: flyvis.datasets.augmentation.hex.PixelNoise
::: flyvis.datasets.augmentation.hex.GammaCorrection

## Temporal Augmentations

::: flyvis.datasets.augmentation.temporal.Interpolate
::: flyvis.datasets.augmentation.temporal.CropFrames

## Base Class

::: flyvis.datasets.augmentation.augmentation.Augmentation

## Utils

::: flyvis.datasets.augmentation.utils
